.Button {
  background: #ffffff;
    color: #000000;
      padding: 3px 16px;
  border-radius: 8px;
    min-height: 10px;
    min-width: 10px;

}

.Button:hover {
  background: #e8e8e8;;
    color: #000000;
  border-radius: 8px;
    min-height: 10px;
    min-width: 10px;

    background-clip: padding-box;
    box-shadow: inset 0 1px rgba(255, 255, 255, 1);
    /*-gtk-icon-shadow: 0 1px black;*/
    outline-color: rgba(254, 254, 254, 1);
}

