#!/usr/bin/python3
# -*- coding: UTF-8 -*-

import os
import sys

var = sys.argv[1].strip()
var2 = os.popen(f"echo {var} | sed 's/.*usb[[:digit:]]//' | sed 's/[a-z].*//'| sed 's/[0-9]-[0-9].//'").readlines()[0]
os.system(f"echo 0 > '/sys/bus/usb/devices{var2.strip()}/authorized'")
